#!/usr/bin/env python

"""
Preparation of templating stylesheets.
"""

import XSLOutput
import libxml2dom
import os

resource_dir = os.path.join(os.path.split(__file__)[0], "XSL")

def make_stylesheet(template_name, output_name, stylesheet_name="Prepare.xsl", encoding="utf-8"):
    global resource_dir
    proc = XSLOutput.Processor([os.path.join(resource_dir, stylesheet_name)])
    template = libxml2dom.parse(template_name)
    proc.send_output(open(output_name, "wb"), encoding, template)

def make_stylesheet_fragment(template_name, output_name, element_id, stylesheet_name="Extract.xsl", encoding="utf-8"):
    global resource_dir
    proc = XSLOutput.Processor([os.path.join(resource_dir, stylesheet_name)], parameters={"element-id" : element_id})
    template = libxml2dom.parse(template_name)
    proc.send_output(open(output_name, "wb"), encoding, template)

def ensure_stylesheet(template_name, output_name):
    if not os.path.exists(output_name) or \
        os.path.getmtime(output_name) < os.path.getmtime(template_name):

        make_stylesheet(template_name, output_name)

def ensure_stylesheet_fragment(template_name, output_name, element_id):
    if not os.path.exists(output_name) or \
        os.path.getmtime(output_name) < os.path.getmtime(template_name):

        make_stylesheet_fragment(template_name, output_name, element_id)

# vim: tabstop=4 expandtab shiftwidth=4
